@@ -2,8 +2,10 @@
 """
 流式请求 统计首token延迟时间（TTFT: time to first token）
 """
+import json
 import time
-from typing import Any, Dict, Optional
+from multiprocessing import Lock
+from typing import Any, Dict, Literal, Optional
 
 from locust import constant, events, task
 from locust.clients import ResponseContextManager
@@ -129,9 +131,7 @@ class QianfanCustomHttpSession(CustomHttpSession):
         """
         context = context or {}
         self.exc = None
-
         request_meta = self._request_internal(context=context, **kwargs)
-
         with ResponseContextManager(
             request_meta["response"],
             request_event=self.request_event,
@@ -145,9 +145,12 @@ class QianfanCustomHttpSession(CustomHttpSession):
                 data, input_column=input_column, output_column=output_column
             )
         elif isinstance(data, dict):
-            ret = self._transfer_json(
-                data, input_column=input_column, output_column=output_column
-            )
+            if input_column not in data and output_column not in data:
+                ret = self._transfer_body(data)
+            else:
+                ret = self._transfer_json(
+                    data, input_column=input_column, output_column=output_column
+                )
         elif isinstance(data, str):
             ret = self._transfer_txt(
                 data, input_column=input_column, output_column=output_column
@@ -171,6 +174,9 @@ class QianfanCustomHttpSession(CustomHttpSession):
     ) -> Any:
         ...
 
+    def _transfer_body(self, data: Any) -> Any:
+        ...
+
 
 class ChatCompletionClient(QianfanCustomHttpSession):
     def __init__(
@@ -181,6 +187,8 @@ class ChatCompletionClient(QianfanCustomHttpSession):
         user: Any,
         *args: Any,
         pool_manager: Optional[PoolManager] = None,
+        version: Literal["1", "2", 1, 2] = "1",
+        app_id: Optional[str] = None,
         **kwargs: Any
     ):
         """
@@ -190,10 +198,30 @@ class ChatCompletionClient(QianfanCustomHttpSession):
             model, request_event, user, *args, pool_manager=pool_manager, **kwargs
         )
         self.model = model
+        self.is_v2 = str(version) == "2"
+
         if is_endpoint:
-            self.chat_comp = qianfan.ChatCompletion(endpoint=model)
+            if self.is_v2:
+                raise ValueError("v2 api doesn't support endpoint")
+
+            self.chat_comp = qianfan.ChatCompletion(
+                endpoint=model,
+                forcing_disable=True,
+                **kwargs,
+            )
         else:
-            self.chat_comp = qianfan.ChatCompletion(model=model)
+            if self.is_v2:
+                self.chat_comp = qianfan.ChatCompletion(
+                    version="2",
+                    model=model,
+                    forcing_disable=True,
+                    app_id=app_id,
+                    **kwargs,
+                )
+            else:
+                self.chat_comp = qianfan.ChatCompletion(
+                    model=model, forcing_disable=True, **kwargs
+                )
 
     def _request_internal(
         self, context: Optional[Dict[str, Any]] = None, **kwargs: Any
@@ -204,17 +232,22 @@ class ChatCompletionClient(QianfanCustomHttpSession):
         else:
             messages = []
         first_flag = True
+
         request_meta: Dict[str, Any] = {
             "input_tokens": 0,
             "output_tokens": 0,
             "response_length": 0,
             "request_length": sum([len(msg) for msg in messages]),
         }
+        header: dict = {}
+        stat: dict = {}
+        merged_query: str = ""
+        body: Dict[str, Any] = {"headers": {}, "stat": {}, "body": ""}
         last_resp = None
         all_empty = True
-
         start_time = time.time()
         start_perf_counter = time.perf_counter()
+
         try:
             kwargs["retry_count"] = 0
             responses = self.chat_comp.do(messages=messages, **kwargs)
@@ -225,40 +258,66 @@ class ChatCompletionClient(QianfanCustomHttpSession):
             setattr(resp, "url", self.model)
             setattr(resp, "reason", str(e))
             setattr(resp, "status_code", 500)
-
         if self.exc is None:
             for resp in responses:
                 setattr(resp, "url", self.model)
                 setattr(resp, "reason", None)
                 setattr(resp, "status_code", resp["code"])
-
-                stream_json = resp["body"]
-                clear_history = stream_json.get("need_clear_history", False)
                 if first_flag:
-                    request_meta["first_token_latency"] = (
-                        time.perf_counter() - start_perf_counter
-                    ) * 1000  # 首Token延迟
+                    request_meta["first_token_latency"] = resp.statistic[
+                        "first_token_latency"
+                    ]
+                    if "first_latency_threshold" in GlobalData.data:
+                        if (
+                            request_meta["first_token_latency"]
+                            > GlobalData.data["first_latency_threshold"]
+                        ):
+                            GlobalData.data["threshold_first"].value = 1
                     first_flag = False
-                content = ""
-                if "result" in stream_json:
-                    content = stream_json["result"]
+                if not self.is_v2:
+                    stream_json = resp["body"]
+                    stat = resp.get("statistic", "")
+                    header = resp.get("headers", "")
+                    body = stream_json
+                    merged_query += stream_json.get("result", "")
+                    clear_history = stream_json.get("need_clear_history", False)
+                    if "result" in stream_json:
+                        content = stream_json["result"]
+                    elif "error_code" in stream_json and stream_json["error_code"] > 0:
+                        self.exc = Exception(
+                            "ERROR CODE {}".format(str(stream_json["error_code"]))
+                        )
+                        break
+                    else:
+                        self.exc = Exception("ERROR CODE 结果无法解析")
+                        break
                 else:
-                    self.exc = Exception("ERROR CODE 结果无法解析")
-                    break
-                if "error_code" in stream_json and stream_json["error_code"] > 0:
-                    self.exc = Exception(
-                        "ERROR CODE {}".format(str(stream_json["error_code"]))
-                    )
-                    break
+                    if "error_code" in resp.body and resp.body["error_code"] > 0:
+                        self.exc = Exception(
+                            "ERROR CODE {}".format(str(resp.body["error_code"]))
+                        )
+                        break
+
+                    stream_json = resp.body["choices"][0]
+                    stat = resp.statistic
+                    header = resp.headers
+                    clear_history = stream_json.get("need_clear_history", False)
+                    if "delta" in stream_json:
+                        content = stream_json["delta"].get("content", "")
+                        merged_query += content
+                    else:
+                        self.exc = Exception("ERROR CODE 结果无法解析")
+                        break
+
                 if len(content) != 0:
                     all_empty = False
                 # 计算token数, 有usage的累加，没有的直接计算content
-                if "usage" in stream_json:
+                if "usage" in resp.body:
                     request_meta["input_tokens"] = int(
-                        stream_json["usage"]["prompt_tokens"]
+                        resp.body["usage"]["prompt_tokens"]
                     )
                     request_meta["output_tokens"] = int(
-                        stream_json["usage"]["completion_tokens"]
+                        resp.body["usage"]["completion_tokens"]
                     )
                 else:
                     request_meta["input_tokens"] = request_meta["request_length"]
@@ -270,24 +329,50 @@ class ChatCompletionClient(QianfanCustomHttpSession):
                 self.exc = Exception("Response is empty")
             elif last_resp is None and self.exc is None:
                 self.exc = Exception("Response is null")
-            elif "is_end" not in last_resp["body"]:
+            elif not self.is_v2 and "is_end" not in last_resp["body"]:
                 self.exc = Exception("Response not finished")
-            elif last_resp["code"] != 200 or not last_resp["body"]["is_end"]:
+            elif last_resp["code"] != 200 or (
+                not self.is_v2 and not last_resp["body"]["is_end"]
+            ):
                 self.exc = Exception("NOT 200 OR is_end is False")
-
         response_time = (time.perf_counter() - start_perf_counter) * 1000
+        body["result"] = merged_query
+        res = {
+            "headers": header,
+            "stat": stat,
+            "body": body,
+        }
+        res_json = json.dumps(res, ensure_ascii=False)
+        if GlobalData.data["log"] == 1:
+            lock = Lock()
+            dir = GlobalData.data["record_dir"]
+            dir = dir + "/" + "query_result.json"
+            with lock:
+                with open(dir, "a") as f:
+                    f.write(res_json + "\n")
+
         if self.user:
             context = {**self.user.context(), **context}
-
-        # store meta data that is used when reporting the request to locust's statistics
-        request_meta["request_type"] = "POST"
-        request_meta["response_time"] = response_time
-        request_meta["name"] = self.model
-        request_meta["context"] = context
-        request_meta["exception"] = self.exc
-        request_meta["start_time"] = start_time
-        request_meta["url"] = self.model
-        request_meta["response"] = last_resp
+        if self.exc is None:
+            # report succeed to locust's statistics
+            request_meta["request_type"] = "POST"
+            request_meta["response_time"] = response_time
+            request_meta["name"] = self.model
+            request_meta["context"] = context
+            request_meta["exception"] = self.exc
+            request_meta["start_time"] = start_time
+            request_meta["url"] = self.model
+            request_meta["response"] = last_resp
+        else:
+            # setting response_time to None when the request is failed
+            request_meta["response_time"] = None
+            request_meta["request_type"] = "POST"
+            request_meta["name"] = self.model
+            request_meta["context"] = context
+            request_meta["exception"] = self.exc
+            request_meta["start_time"] = start_time
+            request_meta["url"] = self.model
+            request_meta["response"] = last_resp
         return request_meta
 
     def _transfer_jsonl(
@@ -320,6 +405,14 @@ class ChatCompletionClient(QianfanCustomHttpSession):
         ret["messages"].append(msg)
         return ret
 
+    def _transfer_body(self, data: Any) -> Any:
+        ret = data
+        if "stream" in ret:
+            del ret["stream"]
+        if "safety_level" in ret and ret["safety_level"] == "none":
+            del ret["safety_level"]
+        return ret
+
 
 class CompletionClient(QianfanCustomHttpSession):
     def __init__(
@@ -330,6 +423,8 @@ class CompletionClient(QianfanCustomHttpSession):
         user: Any,
         *args: Any,
         pool_manager: Optional[PoolManager] = None,
+        version: Literal["1", "2", 1, 2] = "1",
+        app_id: Optional[str] = None,
         **kwargs: Any
     ):
         """
@@ -339,10 +434,26 @@ class CompletionClient(QianfanCustomHttpSession):
             model, request_event, user, *args, pool_manager=pool_manager, **kwargs
         )
         self.model = model
+        self.is_v2 = str(version) == "2"
+
         if is_endpoint:
-            self.comp = qianfan.Completion(endpoint=model)
+            if self.is_v2:
+                raise ValueError("v2 api doesn't support endpoint")
+            else:
+                self.comp = qianfan.Completion(endpoint=model, **kwargs)
         else:
-            self.comp = qianfan.Completion(model=model)
+            if self.is_v2:
+                self.comp = qianfan.Completion(
+                    version="2",
+                    model=model,
+                    app_id=app_id,
+                    forcing_disable=True,
+                    **kwargs,
+                )
+            else:
+                self.comp = qianfan.Completion(
+                    model=model, forcing_disable=True, **kwargs
+                )
 
     def _request_internal(
         self, context: Optional[Dict[str, Any]] = None, **kwargs: Any
@@ -359,6 +470,14 @@ class CompletionClient(QianfanCustomHttpSession):
             "response_length": 0,
             "request_length": len(prompt),
         }
+        header: str
+        stat: str
+        merged_query: str = ""
+        body: Dict[str, Any] = {
+            "headers": {},
+            "stat": {},
+            "body": "",
+        }
         last_resp = None
         all_empty = True
 
@@ -371,10 +490,19 @@ class CompletionClient(QianfanCustomHttpSession):
             setattr(resp, "status_code", resp["code"])
 
             stream_json = resp["body"]
+            stat = resp["statistic"]
+            header = resp["headers"]
+            body = resp["body"]
+            merged_query += stream_json["result"]
             if first_flag:
-                request_meta["first_token_latency"] = (
-                    time.perf_counter() - start_perf_counter
-                ) * 1000  # 首Token延迟
+                request_meta["first_token_latency"] = resp.statistic[
+                    "first_token_latency"
+                ]
+                if (
+                    request_meta["first_token_latency"]
+                    > GlobalData.data["first_latency_threshold"]
+                ):
+                    GlobalData.data["threshold_first"].value = 1
                 first_flag = False
             content = ""
             if "result" in stream_json:
@@ -413,18 +541,43 @@ class CompletionClient(QianfanCustomHttpSession):
             self.exc = Exception("NOT 200 OR is_end is False")
 
         response_time = (time.perf_counter() - start_perf_counter) * 1000
+        body["result"] = merged_query
+        res = {
+            "headers": header,
+            "stat": stat,
+            "body": body,
+        }
+        res_json = json.dumps(res, ensure_ascii=False)
+
+        if GlobalData.data["log"] == 1:
+            lock = Lock()
+            dir = GlobalData.data["record_dir"]
+            dir = dir + "/" + "query_result.json"
+            with lock:
+                with open(dir, "a") as f:
+                    f.write(res_json + "\n")
         if self.user:
             context = {**self.user.context(), **context}
-
-        # store meta data that is used when reporting the request to locust's statistics
-        request_meta["request_type"] = "POST"
-        request_meta["response_time"] = response_time
-        request_meta["name"] = self.model
-        request_meta["context"] = context
-        request_meta["exception"] = self.exc
-        request_meta["start_time"] = start_time
-        request_meta["url"] = self.model
-        request_meta["response"] = last_resp
+        if self.exc is None:
+            # report to locust's statistics
+            request_meta["request_type"] = "POST"
+            request_meta["response_time"] = response_time
+            request_meta["name"] = self.model
+            request_meta["context"] = context
+            request_meta["exception"] = self.exc
+            request_meta["start_time"] = start_time
+            request_meta["url"] = self.model
+            request_meta["response"] = last_resp
+        else:
+            # setting response_time to None when the request is failed
+            request_meta["response_time"] = None
+            request_meta["request_type"] = "POST"
+            request_meta["name"] = self.model
+            request_meta["context"] = context
+            request_meta["exception"] = self.exc
+            request_meta["start_time"] = start_time
+            request_meta["url"] = self.model
+            request_meta["response"] = last_resp
         return request_meta
 
     def _transfer_jsonl(
@@ -445,6 +598,10 @@ class CompletionClient(QianfanCustomHttpSession):
     ) -> Any:
         return dict(prompt=data)
 
+    def _transfer_body(self, data: Any) -> Any:
+        p = data["messages"][0]["content"]
+        return dict(prompt=p)
+
 
 @events.test_start.add_listener
 def test_start(environment: Environment, **kwargs: Any) -> None:
@@ -453,6 +610,7 @@ def test_start(environment: Environment, **kwargs: Any) -> None:
     """
     global distributor
     dataset = GlobalData.data["dataset"]
+    dataset = dataset.list()
     distributor = Distributor(
         environment, iter(dataset)
     )  # Quite runner when iterator raises StopIteration.
@@ -475,6 +633,10 @@ class QianfanLLMLoadUser(CustomUser):
 
         model_type = GlobalData.data["model_type"]
         is_endpoint = GlobalData.data["is_endpoint"]
+
+        app_id = GlobalData.data.get("app_id", None)
+        version = GlobalData.data.get("version", "1")
+
         self.client: QianfanCustomHttpSession
         if model_type == "ChatCompletion":
             self.client = ChatCompletionClient(
@@ -483,6 +645,9 @@ class QianfanLLMLoadUser(CustomUser):
                 request_event=self.environment.events.request,
                 user=self,
                 pool_manager=self.pool_manager,
+                version=version,
+                app_id=app_id,
+                **kwargs,
             )
         elif model_type == "Completion":
             self.client = CompletionClient(  # noqa
@@ -491,6 +656,9 @@ class QianfanLLMLoadUser(CustomUser):
                 request_event=self.environment.events.request,
                 user=self,
                 pool_manager=self.pool_manager,
+                version=version,
+                app_id=app_id,
+                **kwargs,
             )
         else:
             raise Exception("Unsupported model type: %s." % model_type)
@@ -507,7 +675,10 @@ class QianfanLLMLoadUser(CustomUser):
         hyperparameters = GlobalData.data["hyperparameters"]
         assert distributor is not None
         data = next(distributor)
+        self.query_idx += 1
         body = self.client.transfer_data(data, self.input_column, self.output_column)
         if hyperparameters is None:
             hyperparameters = {}
-        self.client.qianfan_request(stream=True, **body, **hyperparameters)
+        self.client.qianfan_request(
+            show_total_latency=True, stream=True, **body, **hyperparameters
+        )
