@@ -20,6 +20,9 @@ from typing import Any, Callable, Dict, List, Optional
 
 from qianfan.consts import Consts
 from qianfan.errors import QianfanError
+from qianfan.resources.console.consts import (
+    V2 as V2Consts,
+)
 from qianfan.resources.console.consts import (
     DataExportDestinationType,
     DataProjectType,
@@ -550,9 +553,7 @@ class Data:
         name: str,
         source_dataset_id: str,
         destination_dataset_id: str,
-        service_name: str,
         dev_api_id: str,
-        service_url: str,
         app_id: int,
         num_seed_fewshot: int,
         num_instances_to_generate: int,
@@ -569,12 +570,8 @@ class Data:
                 dataset id need to be augmented.
             destination_dataset_id (str):
                 where dataset should be stored after augmentation
-            service_name (str):
-                which LLM should be used for augmenting task
             dev_api_id (str):
                 fixed field with value depends on service_name.
-            service_url (str):
-                service url related to service_name
             app_id (int):
                 app id
             num_seed_fewshot (int):
@@ -606,9 +603,7 @@ class Data:
             "isSelfInstruct": True,
             "sourceDatasetId": source_dataset_id,
             "destDatasetId": destination_dataset_id,
-            "serviceName": service_name,
             "devApiId": dev_api_id,
-            "serviceUrl": service_url,
             "appId": app_id,
             "numSeedFewshot": num_seed_fewshot,
             "numInstancesToGenerate": num_instances_to_generate,
@@ -875,11 +870,13 @@ class Data:
     def create_offline_batch_inference_task(
         cls,
         name: str,
-        endpoint: str,
-        input_bos_uri: str,
-        output_bos_uri: str,
+        input_bos_uri: Optional[str] = None,
+        output_bos_uri: Optional[str] = None,
+        model_id: Optional[str] = None,
+        endpoint: Optional[str] = None,
         inference_params: Dict[str, Any] = {},
         description: Optional[str] = None,
+        afs_config: Optional[Dict[str, Any]] = None,
         **kwargs: Any,
     ) -> QfRequest:
         """
@@ -888,14 +885,16 @@ class Data:
         Parameters:
             name (str):
                 Name of the batch inference task
+            model_id (Optional[str]):
+                model id of the model to be used for inference.
             endpoint (str):
-                Endpoint of the model to be used for inference
+                Endpoint of the model to be used for inference.
             input_bos_uri (str):
                 BOS URI of the input data
             output_bos_uri (str):
                 BOS URI of the output data
             inference_params (Dict[str, Any]):
-                The inferece parameters used in the model
+                The inference parameters used in the model
             description (Optional[str]):
                 Description of the batch inference task
 
@@ -910,15 +909,28 @@ class Data:
             query=_get_console_v2_query(
                 Consts.DatasetCreateOfflineBatchInferenceAction
             ),
+            headers={"Referer": "infer"},
         )
         request_json: Dict[str, Any] = {
             "name": name,
-            "endpoint": endpoint,
             "inferenceParams": inference_params,
-            "inputBosUri": input_bos_uri,
-            "outputBosUri": output_bos_uri,
             **kwargs,
         }
+        if afs_config:
+            request_json["afsConfig"] = afs_config
+        elif input_bos_uri and output_bos_uri:
+            request_json["inputBosUri"] = input_bos_uri
+            request_json["outputBosUri"] = output_bos_uri
+        else:
+            raise ValueError(
+                "Either afs_config or input_bos_uri and output_bos_uri must be"
+                " provided."
+            )
+
+        if model_id:
+            request_json["modelId"] = model_id
+        elif endpoint:
+            request_json["endpoint"] = endpoint
 
         if description is not None:
             request_json["description"] = description
@@ -967,6 +979,7 @@ class Data:
         marker: Optional[str] = None,
         max_keys: Optional[int] = None,
         page_reverse: Optional[bool] = None,
+        run_status: Optional[str] = None,
         **kwargs: Any,
     ) -> QfRequest:
         """
@@ -995,10 +1008,502 @@ class Data:
             k: v
             for k, v in {
                 **kwargs,
-                "maker": marker,
+                "marker": marker,
                 "maxKeys": max_keys,
                 "pageReverse": page_reverse,
+                "runStatus": run_status,
             }.items()
             if v is not None
         }
         return req
+
+    class V2:
+        @classmethod
+        def base_api_route(cls) -> str:
+            """
+            base api url route for dataset V2.
+
+            Returns:
+                str: base api url route
+            """
+            return Consts.DatasetV2BaseRouteAPI
+
+        @classmethod
+        @console_api_request
+        def create_dataset(
+            cls,
+            dataset_name: str,
+            dataset_format: V2Consts.DatasetFormat,
+            storage_type: V2Consts.StorageType,
+            storage_path: Optional[str] = None,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            create dataset.
+
+            Parameters:
+                dataset_name (str):
+                    dataset name.
+                dataset_format (V2Consts.DatasetFormat):
+                    dataset format.
+                storage_type (V2Consts.StorageType):
+                    storage type.
+                storage_path (Optional[str], optional):
+                    storage path. Defaults to None.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+            post_body_dict = {
+                "datasetName": dataset_name,
+                "dataFormat": dataset_format.value,
+                "storageType": storage_type.value,
+            }
+
+            if storage_path:
+                if storage_path[-1] != "/":
+                    storage_path += "/"
+
+                post_body_dict["storagePath"] = storage_path
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(Consts.DatasetV2CreateDatasetAction),
+            )
+            req.json_body = post_body_dict
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def get_dataset_list(
+            cls,
+            marker: Optional[str] = None,
+            max_keys: int = 10,
+            page_reverse: bool = False,
+            filter: Optional[Dict[str, Any]] = None,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            get dataset list.
+
+            Parameters:
+                marker (Optional[str], optional):
+                    marker of the first page. Defaults to None.
+                max_keys (int, optional):
+                    max keys of the page. Defaults to 10.
+                page_reverse (bool, optional):
+                    page reverse or not. Defaults to False.
+                filter (Optional[Dict[str, Any]], optional):
+                    filter conditions. Defaults to None.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+            post_json_body: Dict[str, Any] = {
+                "maxKeys": max_keys,
+                "pageReverse": page_reverse,
+            }
+
+            if marker:
+                post_json_body["marker"] = marker
+
+            if filter:
+                post_json_body["filter"] = filter
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(Consts.DatasetV2GetDatasetListAction),
+            )
+            req.json_body = post_json_body
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def delete_dataset(
+            cls,
+            dataset_id: str,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            delete dataset.
+
+            Parameters:
+                dataset_id (str):
+                    dataset id.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+
+            post_body_dict = {
+                "datasetId": dataset_id,
+            }
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(Consts.DatasetV2DeleteDatasetAction),
+            )
+            req.json_body = post_body_dict
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def create_dataset_version(
+            cls,
+            dataset_id: str,
+            description: Optional[str] = None,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            create dataset version.
+
+            Parameters:
+                dataset_id (str):
+                    dataset id.
+                description (Optional[str], optional):
+                    dataset version description. Defaults to None.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+            post_body_dict = {
+                "datasetId": dataset_id,
+            }
+
+            if description:
+                post_body_dict["description"] = description
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(Consts.DatasetV2CreateDatasetVersionAction),
+            )
+            req.json_body = post_body_dict
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def get_dataset_version_info(
+            cls,
+            version_id: str,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            get dataset version info.
+
+            Parameters:
+                version_id (str):
+                    dataset version id.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+
+            post_body_dict = {
+                "versionId": version_id,
+            }
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(
+                    Consts.DatasetV2GetDatasetVersionInfoAction
+                ),
+            )
+            req.json_body = post_body_dict
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def delete_dataset_version(
+            cls,
+            version_id: str,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            delete dataset version.
+
+            Parameters:
+                version_id (str):
+                    dataset version id.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+
+            post_body_dict = {
+                "versionId": version_id,
+            }
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(Consts.DatasetV2DeleteDatasetVersionAction),
+            )
+            req.json_body = post_body_dict
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def publish_dataset_version(
+            cls,
+            version_id: str,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            publish dataset version.
+
+            Parameters:
+                version_id (str):
+                    dataset version id.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+
+            post_body_dict = {
+                "versionId": version_id,
+            }
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(
+                    Consts.DatasetV2PublishDatasetVersionAction
+                ),
+            )
+            req.json_body = post_body_dict
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def get_dataset_version_list(
+            cls,
+            dataset_id: str,
+            marker: Optional[str] = None,
+            max_keys: int = 10,
+            page_reverse: bool = False,
+            filter: Optional[Dict[str, Any]] = None,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            get dataset version list.
+
+            Parameters:
+                dataset_id (str):
+                    dataset id.
+                marker (Optional[str], optional):
+                    marker. Defaults to None.
+                max_keys (int, optional):
+                    max keys. Defaults to 10.
+                page_reverse (bool, optional):
+                    page reverse. Defaults to False.
+                filter (Optional[Dict[str, Any]], optional):
+                    filter. Defaults to None.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+
+            post_body_dict = {
+                "datasetId": dataset_id,
+                "maxKeys": max_keys,
+                "pageReverse": page_reverse,
+            }
+
+            if marker:
+                post_body_dict["marker"] = marker
+
+            if filter:
+                post_body_dict["filter"] = filter
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(
+                    Consts.DatasetV2GetDatasetVersionListAction
+                ),
+            )
+            req.json_body = post_body_dict
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def create_dataset_version_import_task(
+            cls,
+            version_id: str,
+            files: List[str],
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            create dataset version import task.
+
+            Parameters:
+                version_id (str):
+                    dataset version id.
+                files (List[str]):
+                    file paths.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+
+            post_body_dict = {
+                "versionId": version_id,
+                "files": files,
+            }
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(
+                    Consts.DatasetV2CreateDatasetVersionImportTaskAction
+                ),
+            )
+            req.json_body = post_body_dict
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def get_dataset_version_import_task_info(
+            cls,
+            task_id: str,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            get dataset version import task info.
+
+            Parameters:
+                task_id (str):
+                    task id.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+
+            post_body_dict = {
+                "taskId": task_id,
+            }
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(
+                    Consts.DatasetV2GetDatasetVersionImportTaskInfoAction
+                ),
+            )
+            req.json_body = post_body_dict
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def create_dataset_version_export_task(
+            cls,
+            version_id: str,
+            storage_type: V2Consts.StorageType,
+            storage_path: Optional[str] = None,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            create dataset version export task.
+
+            Parameters:
+                version_id (str):
+                    dataset version id.
+                storage_type (V2Consts.StorageType):
+                    storage type.
+                storage_path (Optional[str], optional):
+                    storage path. Defaults to None.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+
+            post_body_dict = {
+                "versionId": version_id,
+                "storageType": storage_type.value,
+            }
+
+            if storage_path:
+                post_body_dict["storagePath"] = storage_path
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(
+                    Consts.DatasetV2CreateDatasetVersionExportTaskAction
+                ),
+            )
+            req.json_body = post_body_dict
+
+            return req
+
+        @classmethod
+        @console_api_request
+        def get_dataset_version_export_task_info(
+            cls,
+            task_id: str,
+            **kwargs: Any,
+        ) -> QfRequest:
+            """
+            get dataset version export task info.
+
+            Parameters:
+                task_id (str):
+                    task id.
+
+            Note:
+                The `@console_api_request` decorator is applied to this method,
+                enabling it to send the generated QfRequest
+                and return a QfResponse to the user.
+            """
+
+            post_body_dict = {
+                "taskId": task_id,
+            }
+
+            req = QfRequest(
+                method="POST",
+                url=cls.base_api_route(),
+                query=_get_console_v2_query(
+                    Consts.DatasetV2GetDatasetVersionExportTaskInfoAction
+                ),
+            )
+            req.json_body = post_body_dict
+
+            return req
