@@ -76,9 +76,9 @@ class FineTune(object):
           name (str):
             The name of the fine-tuning task.
           base_train_type (str):
-            The base training type of the fine-tuning task. e.g. "ERNIE-Bot-turbo"
+            The base training type of the fine-tuning task. e.g. "ERNIE-Speed-8K"
           train_type (str):
-            The training type of the fine-tuning task. e.g. "ERNIE-Bot-turbo-0922
+            The training type of the fine-tuning task. e.g. "ERNIE-Speed-8K
           description (Optional[str]):
             An optional description for the fine-tuning task.
           kwargs (Any):
@@ -230,10 +230,13 @@ class FineTune(object):
             cls,
             job_id: str,
             params_scale: Union[str, console_consts.TrainParameterScale],
-            hyper_params: Dict[str, Any],
-            dataset_config: Dict[str, Any],
+            hyper_params: Dict[str, Any] = {},
+            dataset_config: Optional[Dict[str, Any]] = None,
             increment_task_id: Optional[str] = None,
             increment_checkpoint_step: Optional[int] = None,
+            model_config: Optional[Dict[str, Any]] = None,
+            resource_config: Optional[Dict[str, Any]] = None,
+            corpus_config: Optional[Dict[str, Any]] = None,
             **kwargs: Any,
         ) -> QfRequest:
             """
@@ -255,6 +258,13 @@ class FineTune(object):
                 The task id of the increment task.
             increment_checkpoint_step (Optional[int]):
                 The checkpoint step for the increment task.
+            model_config (Optional[Dict[str, Any]]):
+                The model config of the fine-tuning task for custom_mode training.
+            resource_config (Optional[Dict[str, Any]]):
+                The resource config of the fine-tuning task, which can indicates
+                the specific private resources.
+            corpus_config (Optional[Dict[str, Any]]):
+                The corpus config of the fine-tuning task for data enhancement.
             kwargs:
                 Additional keyword arguments that can be passed to customize
                 the request.
@@ -268,6 +278,8 @@ class FineTune(object):
                 url=cls.base_api_route(),
                 query=_get_console_v2_query(Consts.FineTuneCreateTaskAction),
             )
+            if dataset_config is None:
+                raise ValueError("dataset_config cannot be empty")
             req.json_body = {
                 **kwargs,
                 "jobId": job_id,
@@ -283,6 +295,12 @@ class FineTune(object):
                 req.json_body["incrementTaskId"] = increment_task_id
                 if increment_checkpoint_step is not None:
                     req.json_body["incrementCheckpointStep"] = increment_checkpoint_step
+            if model_config is not None:
+                req.json_body["modelConfig"] = model_config
+            if resource_config is not None:
+                req.json_body["resourceConfig"] = resource_config
+            if corpus_config is not None:
+                req.json_body["corpusConfig"] = corpus_config
             return req
 
         @classmethod
@@ -329,7 +347,7 @@ class FineTune(object):
                         if isinstance(train_model, console_consts.TrainMode)
                         else train_model
                     ),
-                    "maker": marker,
+                    "marker": marker,
                     "maxKeys": max_keys,
                     "pageReverse": page_reverse,
                 }.items()
@@ -377,7 +395,7 @@ class FineTune(object):
                 for k, v in {
                     **kwargs,
                     "jobId": job_id,
-                    "maker": marker,
+                    "marker": marker,
                     "maxKeys": max_keys,
                     "pageReverse": page_reverse,
                 }.items()
