@@ -15,9 +15,10 @@
 """
 Qianfan API Requestor
 """
-
 import copy
 import json
+import os
+from datetime import datetime
 from typing import (
     Any,
     AsyncIterator,
@@ -25,6 +26,7 @@ from typing import (
     Callable,
     Dict,
     Iterator,
+    List,
     Optional,
     TypeVar,
     Union,
@@ -62,7 +64,6 @@ class QfAPIRequestor(BaseAPIRequestor):
         `ak`, `sk` and `access_token` can be provided in kwargs.
         """
         super().__init__(**kwargs)
-        self._auth = Auth(**kwargs)
         self._token_limiter = TokenLimiter(**kwargs)
         self._async_token_limiter = AsyncTokenLimiter(**kwargs)
 
@@ -100,9 +101,22 @@ class QfAPIRequestor(BaseAPIRequestor):
         responses = self._client.request_stream(request)
 
         _, resp = next(responses)
-        if "json" in resp.headers.get("content-type", ""):
-            body, resp = next(responses)
-            self._check_error(json.loads(body))
+        if "json" in resp.headers.get("content-type", "") or resp.status_code != 200:
+            try:
+                status_code = resp.status_code
+                body, resp = next(responses)
+                self._check_error(json.loads(body))
+            except Exception as e:
+                log_error(
+                    f"stream ended with status code: {status_code}, error: {e},"
+                    f" headers: {resp.headers}"
+                )
+                raise e
+
+        if "X-Ratelimit-Limit-Requests" in resp.headers:
+            self._rate_limiter.reset_once(
+                float(resp.headers["X-Ratelimit-Limit-Requests"])
+            )
 
         def iter() -> Iterator[QfResponse]:
             event = ""
@@ -113,7 +127,7 @@ class QfAPIRequestor(BaseAPIRequestor):
                     body, resp = next(responses)
                 except StopIteration:
                     break
-                _check_if_status_code_is_200(resp)
+                _check_if_status_code_is_200(resp, self.config)
                 body_str = body.decode("utf-8")
                 if body_str == "":
                     continue
@@ -131,7 +145,7 @@ class QfAPIRequestor(BaseAPIRequestor):
                             token_refreshed = True
                             self._auth.refresh_access_token()
                             self._add_access_token(request)
-                            with self._rate_limiter:
+                            with self._rate_limiter.acquire():
                                 responses = self._client.request_stream(request)
                             continue
                         raise
@@ -145,13 +159,17 @@ class QfAPIRequestor(BaseAPIRequestor):
                         f"got unexpected stream response from server: {body_str}"
                     )
                 body_str = body_str[len(Consts.STREAM_RESPONSE_PREFIX) :]
-                json_body = json.loads(body_str)
+                if body_str != Consts.V2_STREAM_RESPONSE_END_NOTE:
+                    json_body = json.loads(body_str)
+                else:
+                    return
                 if event != "":
                     json_body["_event"] = event
                     event = ""
                 parsed = self._parse_response(json_body, resp)
                 parsed.request = QfRequest.from_requests(resp.request)
                 parsed.request.json_body = copy.deepcopy(request.json_body)
+                parsed.request.retry_config = request.retry_config
                 parsed.statistic["first_token_latency"] = resp.elapsed.total_seconds()
                 yield data_postprocess(parsed)
 
@@ -193,14 +211,30 @@ class QfAPIRequestor(BaseAPIRequestor):
         responses = self._client.arequest_stream(request)
 
         _, resp = await responses.__anext__()
-        if "json" in resp.headers.get("content-type", ""):
-            body, _ = await responses.__anext__()
-            self._check_error(json.loads(body))
+        if "X-Ratelimit-Limit-Requests" in resp.headers:
+            await self._rate_limiter.async_reset_once(
+                float(resp.headers["X-Ratelimit-Limit-Requests"])
+            )
+
+        if "json" in resp.headers.get("content-type", "") or resp.status != 200:
+            try:
+                status_code = resp.status
+                body, _ = await responses.__anext__()
+                self._check_error(json.loads(body))
+            except Exception as e:
+                log_error(
+                    f"stream ended with status code: {status_code}, error: {e},"
+                    f" headers: {resp.headers}"
+                )
+                await responses.aclose()
+                raise e
 
         async def iter() -> AsyncIterator[QfResponse]:
             nonlocal responses
             token_refreshed = False
+            count = 0
             async for body, resp in responses:
+                count += 1
                 _async_check_if_status_code_is_200(resp)
                 body_str = body.decode("utf-8")
                 if body_str.strip() == "":
@@ -218,7 +252,7 @@ class QfAPIRequestor(BaseAPIRequestor):
                             token_refreshed = True
                             await self._auth.arefresh_access_token()
                             await self._async_add_access_token(request)
-                            async with self._rate_limiter:
+                            async with self._rate_limiter.acquire():
                                 responses = self._client.arequest_stream(request)
                             continue
                         raise
@@ -226,10 +260,14 @@ class QfAPIRequestor(BaseAPIRequestor):
                         f"got unexpected stream response from server: {body_str}"
                     )
                 body_str = body_str[len(Consts.STREAM_RESPONSE_PREFIX) :]
-                json_body = json.loads(body_str)
+                if not body_str.startswith(Consts.V2_STREAM_RESPONSE_END_NOTE):
+                    json_body = json.loads(body_str)
+                else:
+                    return
                 parsed = await self._parse_async_response(json_body, resp)
                 parsed.request = QfRequest.from_aiohttp(resp.request_info)
                 parsed.request.json_body = copy.deepcopy(request.json_body)
+                parsed.request.retry_config = request.retry_config
                 yield data_postprocess(parsed)
 
         return iter()
@@ -249,7 +287,7 @@ class QfAPIRequestor(BaseAPIRequestor):
                 possible_reason = (
                     "IAM 鉴权失败，请检查 Access Key 与 Secret Key 是否正确，"
                     "当前使用的 Access Key 为"
-                    f" `{_masked_ak(get_config().ACCESS_KEY or '')}`"
+                    f" `{_masked_ak(self.config.ACCESS_KEY or '')}`"
                 )
             elif error_code == APIErrorCode.DailyLimitReached.value:
                 possible_reason = "未开通所调用服务的付费权限，或者账户已欠费"
@@ -303,8 +341,13 @@ class QfAPIRequestor(BaseAPIRequestor):
                 content = message.get("content", None)
                 if not content:
                     continue
-
-                token_count += self._token_limiter.tokenizer.count_tokens(content)
+                if isinstance(content, str):
+                    token_count += self._token_limiter.tokenizer.count_tokens(content)
+                elif isinstance(content, List):
+                    for ct in content:
+                        token_count += self._token_limiter.tokenizer.count_tokens(
+                            ct.get("text", "")
+                        )
 
         if prompt:
             assert isinstance(prompt, str)
@@ -391,11 +434,18 @@ class QfAPIRequestor(BaseAPIRequestor):
         stream: bool = False,
         data_postprocess: Callable[[QfResponse], QfResponse] = lambda x: x,
         retry_config: RetryConfig = RetryConfig(),
+        show_total_latency: bool = False,
     ) -> Union[QfResponse, Iterator[QfResponse]]:
         """
         llm related api request
         """
         log_debug(f"requesting llm api endpoint: {endpoint}")
+        # TODO 应该放在Adapter中做处理。
+        for m in body.get("messages", []):
+            if m.get("role", "") == "function":
+                if not m.get("name", None):
+                    m["name"] = m.get("tool_call_id", "")
+                    m.pop("tool_call_id", None)
 
         @self._retry_if_token_expired
         def _helper() -> Union[QfResponse, Iterator[QfResponse]]:
@@ -410,11 +460,34 @@ class QfAPIRequestor(BaseAPIRequestor):
             token_count = self._get_token_count_from_body(body)
             self._token_limiter.decline(token_count)
 
+            def _generator_wrapper(
+                generator: Iterator[QfResponse],
+            ) -> Iterator[QfResponse]:
+                for res in generator:
+                    if not show_total_latency:
+                        res.statistic["total_latency"] = 0
+                        res.statistic["request_latency"] = 0
+
+                    yield res
+
+            def _list_generator(data: List) -> Any:
+                for res in data:
+                    yield res
+
             if stream:
-                return self._compensate_token_usage_stream(
+                generator = self._compensate_token_usage_stream(
                     self._request_stream(req, data_postprocess=data_postprocess),
                     token_count,
                 )
+
+                if not show_total_latency:
+                    return _generator_wrapper(generator)
+                else:
+                    result_list: List[QfResponse] = []
+                    for res in generator:
+                        result_list.append(res)
+
+                    return _list_generator(result_list)
             else:
                 return self._compensate_token_usage_non_stream(
                     self._request(
@@ -435,11 +508,33 @@ class QfAPIRequestor(BaseAPIRequestor):
         stream: bool = False,
         data_postprocess: Callable[[QfResponse], QfResponse] = lambda x: x,
         retry_config: RetryConfig = RetryConfig(),
+        show_total_latency: bool = False,
     ) -> Union[QfResponse, AsyncIterator[QfResponse]]:
         """
         llm related api request
         """
         log_debug(f"async requesting llm api endpoint: {endpoint}")
+        for m in body.get("messages", []):
+            if m.get("role", "") == "function":
+                if not m.get("name", None):
+                    m["name"] = m.get("tool_call_id", "")
+                    m.pop("tool_call_id", None)
+
+        class AsyncListIterator:
+            def __init__(self, data: List[QfResponse]):
+                self.data = data
+                self.index = 0
+
+            def __aiter__(self) -> "AsyncListIterator":
+                return self
+
+            async def __anext__(self) -> Any:
+                if self.index < len(self.data):
+                    value = self.data[self.index]
+                    self.index += 1
+                    return value
+                else:
+                    raise StopAsyncIteration
 
         @self._async_retry_if_token_expired
         async def _helper() -> Union[QfResponse, AsyncIterator[QfResponse]]:
@@ -454,13 +549,32 @@ class QfAPIRequestor(BaseAPIRequestor):
             token_count = self._get_token_count_from_body(body)
             await self._async_token_limiter.decline(token_count)
 
+            async def _async_generator_wrapper(
+                generator: AsyncIterator[QfResponse],
+            ) -> AsyncIterator[QfResponse]:
+                async for res in generator:
+                    if not show_total_latency:
+                        res.statistic["total_latency"] = 0
+                        res.statistic["request_latency"] = 0
+
+                    yield res
+
             if stream:
-                return self._async_compensate_token_usage_stream(
+                generator = self._async_compensate_token_usage_stream(
                     await self._async_request_stream(
                         req, data_postprocess=data_postprocess
                     ),
                     token_count,
                 )
+
+                if not show_total_latency:
+                    return _async_generator_wrapper(generator)
+                else:
+                    result_list: List[QfResponse] = []
+                    async for res in generator:
+                        result_list.append(res)
+
+                    return AsyncListIterator(result_list)
             else:
                 return await self._async_compensate_token_usage_non_stream(
                     await self._async_request(req, data_postprocess=data_postprocess),
@@ -494,12 +608,16 @@ class QfAPIRequestor(BaseAPIRequestor):
         """
         url = request.url
         parsed_uri = urlparse(request.url)
-        host = parsed_uri.netloc
+        if os.environ.get("QIANFAN_IAM_HOST"):
+            host = str(os.environ.get("QIANFAN_IAM_HOST"))
+            parsed_uri = parsed_uri._replace(scheme="https", netloc=host)
+        else:
+            host = parsed_uri.netloc
         request.url = parsed_uri.path
         request.headers = {
             "Content-Type": "application/json",
             "Host": host,
-            **request.headers,
+            **(request.headers if request.headers else {}),
         }
         iam_sign(ak, sk, request)
         request.url = url
@@ -510,6 +628,9 @@ class QfAPIRequestor(BaseAPIRequestor):
         """
         add access token to QfRequest
         """
+        if self.config.NO_AUTH:
+            # 配置无鉴权，不签名，不抛出需要刷新token的异常，直接跳出。
+            return req
         if auth is None:
             auth = self._auth
         access_token = auth.access_token()
@@ -531,6 +652,9 @@ class QfAPIRequestor(BaseAPIRequestor):
         """
         async add access token to QfRequest
         """
+        if self.config.NO_AUTH:
+            # 配置无鉴权，不签名，不抛出需要刷新token的异常，直接跳出。
+            return req
         if auth is None:
             auth = self._auth
         access_token = await auth.a_access_token()
@@ -551,8 +675,8 @@ class QfAPIRequestor(BaseAPIRequestor):
         convert endpoint to llm api url
         """
         return "{}{}{}".format(
-            get_config().BASE_URL,
-            Consts.ModelAPIPrefix,
+            self.config.BASE_URL,
+            self.config.MODEL_API_PREFIX,
             endpoint,
         )
 
@@ -563,7 +687,6 @@ class QfAPIRequestor(BaseAPIRequestor):
 
         @self._retry_if_token_expired
         def _helper() -> QfResponse:
-            self._add_access_token(req, auth)
             return self._request(req)
 
         return self._with_retry(req.retry_config, _helper)
@@ -577,19 +700,43 @@ class QfAPIRequestor(BaseAPIRequestor):
 
         @self._async_retry_if_token_expired
         async def _helper() -> QfResponse:
-            await self._async_add_access_token(req, auth)
             return await self._async_request(req)
 
         return self._async_with_retry(req.retry_config, _helper)
 
 
 class QfAPIV2Requestor(QfAPIRequestor):
+    def __init__(self, **kwargs: Any) -> None:
+        super().__init__(refresh_func=self._refresh_bearer_token, **kwargs)
+
+    def _refresh_bearer_token(self, *args: Any, **kwargs: Any) -> Dict:
+        """
+        refresh bearer token
+        """
+        from qianfan.resources.console.iam import IAM
+
+        resp = IAM.create_bearer_token(
+            expire_in_seconds=self.config.BEARER_TOKEN_EXPIRED_INTERVAL,
+            ak=self._auth._access_key,
+            sk=self._auth._secret_key,
+        )
+
+        def _convert_time_str_to_sec(time_str: str) -> float:
+            dt = datetime.fromisoformat(time_str.replace("Z", "+00:00"))
+            return dt.timestamp()
+
+        return {
+            "token": resp.body["token"],
+            "refresh_at": _convert_time_str_to_sec(resp.body["createTime"]),
+            "expire_at": _convert_time_str_to_sec(resp.body["expireTime"]),
+        }
+
     def _llm_api_url(self, endpoint: str) -> str:
         """
         convert endpoint to llm api url
         """
         return "{}{}".format(
-            get_config().CONSOLE_API_BASE_URL,
+            self.config.CONSOLE_API_BASE_URL,
             endpoint,
         )
 
@@ -597,30 +744,42 @@ class QfAPIV2Requestor(QfAPIRequestor):
         self, req: QfRequest, auth: Optional[Auth] = None
     ) -> QfRequest:
         """
-        add access token to QfRequest
+        add bearer token to QfRequest V2
         """
+        if self.config.NO_AUTH:
+            # 配置无鉴权，不签名，不抛出需要刷新token的异常，直接跳出。
+            return req
         if auth is None:
             auth = self._auth
-
-        # use IAM auth
-        access_key = auth._access_key
-        secret_key = auth._secret_key
-        if access_key is None or secret_key is None:
-            extra_msg = ""
-            if get_config().AK is not None or get_config().SK is not None:
-                extra_msg = (
-                    " AK and SK cannot be used in V2 API. V2 推理 API 不支持通过 AK 和"
-                    " SK 进行鉴权，请换用 access_key 和 secret_key。"
-                )
-            raise errors.InvalidArgumentError(
-                "access_key and secret_key must be provided! 未提供 access_key 或"
-                " secret_key！"
-                + extra_msg
-            )
-        self._sign(req, access_key, secret_key)
-
+        bearer_token = auth.bearer_token()
+        if bearer_token == "":
+            raise errors.BearerTokenExpiredError
+        else:
+            # use openapi auth
+            req.headers["Authorization"] = f"Bearer {bearer_token}"
         return req
 
+    def _retry_if_token_expired(self, func: Callable[..., _T]) -> Callable[..., _T]:
+        """
+        this is a wrapper to deal with token expired error
+        """
+        token_refreshed = False
+
+        def retry_wrapper(*args: Any, **kwargs: Any) -> _T:
+            nonlocal token_refreshed
+            # if token is refreshed, token expired exception will not be dealt with
+            if not token_refreshed:
+                try:
+                    return func(*args)
+                except errors.BearerTokenExpiredError:
+                    # refresh token and set token_refreshed flag
+                    self._auth.refresh_bearer_token()
+                    token_refreshed = True
+                    # then fallthrough and try again
+            return func(*args, **kwargs)
+
+        return retry_wrapper
+
     async def _async_add_access_token(
         self, req: QfRequest, auth: Optional[Auth] = None
     ) -> QfRequest:
@@ -650,6 +809,9 @@ class QfAPIV2Requestor(QfAPIRequestor):
 
             raise errors.APIError(error_code, err_msg, req_id)
 
+        # TODO 加上过期的raise BearerTokenExpiredError
+        # 当前无法区分
+
 
 def create_api_requestor(*args: Any, **kwargs: Any) -> QfAPIRequestor:
     if get_config().ENABLE_PRIVATE:
@@ -686,7 +848,7 @@ class PrivateAPIRequestor(QfAPIRequestor):
         req = QfRequest(
             method="POST",
             url="{}{}".format(
-                Consts.ModelAPIPrefix,
+                get_config().MODEL_API_PREFIX,
                 endpoint,
             ),
         )
@@ -705,6 +867,7 @@ class PrivateAPIRequestor(QfAPIRequestor):
         stream: bool = False,
         data_postprocess: Callable[[QfResponse], QfResponse] = lambda x: x,
         retry_config: RetryConfig = RetryConfig(),
+        show_total_latency: bool = False,
     ) -> Union[QfResponse, Iterator[QfResponse]]:
         """
         llm related api request
