@@ -13,12 +13,12 @@
 # limitations under the License.
 import copy
 import time
-from pathlib import Path
 from typing import Any, Dict, List, Optional, Union, cast
 
 from qianfan import resources as api
 from qianfan.config import get_config
 from qianfan.dataset import BosDataSource, Dataset, QianfanDataSource
+from qianfan.dataset.data_source import DataSource
 from qianfan.errors import InternalError, InvalidArgumentError
 from qianfan.evaluation import EvaluationManager
 from qianfan.evaluation.evaluator import Evaluator, LocalEvaluator, QianfanEvaluator
@@ -31,13 +31,13 @@ from qianfan.trainer.base import (
     with_event,
 )
 from qianfan.trainer.configs import (
+    CorpusConfig,
+    CorpusConfigItem,
     DatasetConfig,
-    DefaultDPOTrainConfigMapping,
-    DefaultPostPretrainTrainConfigMapping,
-    DefaultTrainConfigMapping,
     PeftType,
     TrainConfig,
     TrainLimit,
+    get_default_train_config,
     get_model_info,
 )
 from qianfan.trainer.consts import ServiceStatus, TrainStatus
@@ -49,7 +49,7 @@ from qianfan.utils import (
     log_warn,
     utils,
 )
-from qianfan.utils.bos_uploader import is_valid_bos_path
+from qianfan.utils.bos_uploader import is_valid_bos_path, parse_bos_path
 from qianfan.utils.utils import first_lower_case, snake_to_camel
 
 
@@ -82,51 +82,78 @@ class LoadDataSetAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
         ```
     """
 
-    from qianfan.dataset.dataset import Dataset
-
-    dataset: Optional[Dataset] = None
-    bos_path: Optional[str] = None
+    datasets: List[Union[DataSource, Dict]] = []
+    sampling_rates: List[float] = []
     result: Optional[Dict[str, Any]] = None
-    corpus_proportion: Optional[float] = None
-    corpus_type: Optional[console_consts.FinetuneCorpusType] = None
-    corpus_labels: Optional[List[str]] = None
     eval_split_ratio: Optional[float] = None
-    sampling_rate: Optional[float] = None
+    corpus_config: Optional[CorpusConfig] = None
+    source_type: Optional[console_consts.TrainDatasetSourceType] = None
 
     def __init__(
         self,
-        dataset: Union[DatasetConfig, Dataset, str],
+        dataset: Union[DatasetConfig, Dataset, str, List[str]],
         dataset_template: Optional[console_consts.DataTemplateType] = None,
+        corpus_config: Optional[CorpusConfig] = None,
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
         self.eval_split_ratio = kwargs.get("eval_split_ratio", 20)
-        self.corpus_proportion = kwargs.get("corpus_proportion")
-        self.corpus_type = kwargs.get("corpus_type")
-        self.corpus_labels = kwargs.get("corpus_labels")
-        self.sampling_rate = kwargs.get("sampling_rate")
+
+        global_sampling_rate = kwargs.get("sampling_rate")
+        if kwargs.get("corpus_type"):
+            self.corpus_config = CorpusConfig()
+            self.corpus_config.corpus_configs.append(CorpusConfigItem(**kwargs))
+        if isinstance(dataset, str):
+            dataset = [dataset]
+
         if isinstance(dataset, DatasetConfig):
-            assert isinstance(dataset.datasets[0], Dataset)
-            self.dataset = dataset.datasets[0]
-            if dataset.corpus_proportion is not None:
-                self.corpus_proportion = dataset.corpus_proportion
-            if dataset.corpus_type is not None:
-                self.corpus_type = dataset.corpus_type
-            if dataset.corpus_labels is not None:
-                self.corpus_labels = dataset.corpus_labels
+            global_sampling_rate = global_sampling_rate or dataset.sampling_rate
+            if isinstance(dataset.datasets[0], Dataset):
+                self.datasets = [ds.inner_data_source_cache for ds in dataset.datasets]
+            elif isinstance(dataset.datasets[0], DataSource):
+                self.datasets = dataset.datasets
+            elif isinstance(dataset.datasets[0], dict):
+                self.datasets = dataset.datasets
+            if dataset.sampling_rates:
+                self.sampling_rates = dataset.sampling_rates
+            if self.corpus_config is None:
+                self.corpus_config = CorpusConfig()
+            if dataset.corpus_type:
+                self.corpus_config.corpus_configs.append(
+                    CorpusConfigItem(  # type:ignore
+                        corpus_proportion=dataset.corpus_proportion,
+                        corpus_type=dataset.corpus_type,
+                        corpus_labels=dataset.corpus_labels,
+                    )
+                )
             if dataset.eval_split_ratio is not None:
                 self.eval_split_ratio = dataset.eval_split_ratio
-            if dataset.sampling_rate is not None:
-                self.sampling_rate = dataset.sampling_rate
-        elif isinstance(dataset, str):
-            if is_valid_bos_path(dataset):
-                self.bos_path = dataset
-                self._dataset_str = dataset
-            elif dataset.startswith("ds-"):
-                self.dataset = Dataset.load(qianfan_dataset_id=dataset)
-                self._dataset_str = dataset
-            else:
-                raise InvalidArgumentError(f"invalid dataset_str: {dataset}")
+
+            if dataset.sampling_rates is None and global_sampling_rate:
+                self.sampling_rates = [
+                    global_sampling_rate for i in range(len(self.datasets))
+                ]
+            if self.sampling_rates and len(self.datasets) != len(self.sampling_rates):
+                raise ValueError("sampling_rates not with the same counts to datasets")
+            if dataset.source_type:
+                self.source_type = console_consts.TrainDatasetSourceType(
+                    dataset.source_type
+                )
+        elif isinstance(dataset, list):
+            if len(dataset) > 0:
+                if isinstance(dataset[0], str):
+                    for ds_str in dataset:
+                        if is_valid_bos_path(ds_str):
+                            bos_ds_src = LoadDataSetAction.create_bos_ds_src(ds_str)
+                            self.datasets.append(bos_ds_src)
+                        elif ds_str.startswith("ds-"):
+                            self.datasets.append(
+                                QianfanDataSource.get_existed_dataset(ds_str)
+                            )
+                        else:
+                            raise InvalidArgumentError(f"invalid dataset_str: {ds_str}")
+                elif isinstance(dataset[0], Dataset):
+                    self.datasets = dataset
         elif isinstance(dataset.inner_data_source_cache, QianfanDataSource):
             qf_data_src = cast(QianfanDataSource, dataset.inner_data_source_cache)
             if (
@@ -136,16 +163,20 @@ class LoadDataSetAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
                 raise InvalidArgumentError(
                     f"dataset must be `{dataset_template}` template."
                 )
-            self.dataset = dataset
-            self._dataset_str = dataset.inner_data_source_cache.id
+            self.datasets = [dataset.inner_data_source_cache]
         elif isinstance(dataset.inner_data_source_cache, BosDataSource):
-            self.dataset = dataset
-            self.bos_path = dataset.inner_data_source_cache.bos_file_path
+            self.datasets = [dataset.inner_data_source_cache]
         else:
             raise InvalidArgumentError(
                 "dataset must be either implemented with QianfanDataSource or"
                 " BosDataSource or a bos path"
             )
+        if global_sampling_rate and self.sampling_rates is None:
+            self.sampling_rates = [
+                global_sampling_rate for i in range(len(self.datasets))
+            ]
+        if corpus_config is not None:
+            self.corpus_config = corpus_config
 
     @with_event
     def exec(self, input: Dict[str, Any] = {}, **kwargs: Dict) -> Dict[str, Any]:
@@ -154,84 +185,137 @@ class LoadDataSetAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
             return resp
         if self.eval_split_ratio is not None:
             resp["datasets"]["splitRatio"] = self.eval_split_ratio
-        if self.corpus_proportion:
-            resp["datasets"]["corpusProportion"] = f"{self.corpus_proportion}%"
-        if self.sampling_rate:
-            for d in resp["datasets"]["versions"]:
-                d["samplingRate"] = self.sampling_rate
-        if self.corpus_type:
-            resp["datasets"]["corpusProportionType"] = int(self.corpus_type)
-        if self.corpus_labels:
-            resp["datasets"]["corpusProportionLabels"] = self.corpus_labels
+        if self.corpus_config and len(self.corpus_config.corpus_configs) > 0:
+            resp["corpus_config"] = self.corpus_config.dict(
+                by_alias=True, exclude_none=True
+            )
+        if self.sampling_rates:
+            for i, d in enumerate(resp["datasets"]["versions"]):
+                d["samplingRate"] = self.sampling_rates[i]
         return resp
 
     def _exec(self, input: Dict[str, Any] = {}, **kwargs: Dict) -> Dict[str, Any]:
         """
         Load dataset implementation, may called by exec and resume.
         """
-        if self.bos_path is not None:
-            if not self.bos_path.endswith("/"):
-                bos_path = f'{Path(f"/{self.bos_path}").parent}'
-                log_warn(
-                    f"input bos_path {self.bos_path} is a file, auto_convert to dir:"
-                    f" {bos_path}"
-                )
-            else:
-                bos_path = self.bos_path
-            self.result = {
-                "datasets": {
-                    "sourceType": (
-                        console_consts.TrainDatasetSourceType.PrivateBos.value
-                    ),
-                    "versions": [{"versionBosUri": bos_path}],
-                }
-            }
-            return self.result
+        result = self.get_action_result(**kwargs)
+        if len(result["datasets"]["versions"]) == 0:
+            raise InvalidArgumentError(
+                "dataset must be set or input dataset is invalid"
+            )
+        self.result = result
+        return result
+
+    def get_action_result(self, **kwargs: Any) -> Dict[str, Any]:
+        result: Dict[str, Any] = {}
+        versions: List[Dict[str, Any]] = []
+        for i, dataset in enumerate(self.datasets):
+            if isinstance(dataset, Dict):
+                version = dataset
+            elif isinstance(dataset, DataSource):
+                sub_res = self.get_dataset_result(dataset, **kwargs)
+                if sub_res is None:
+                    log_warn(f"invalid dataset {dataset}")
+                    continue
+                if result.get("sourceType") and sub_res.get("sourceType") != result.get(
+                    "sourceType"
+                ):
+                    log_warn(
+                        "[load_dataset_action] dataset sourceType conflict, should all"
+                        f" be with one source type{sub_res}"
+                    )
+                else:
+                    self.source_type = sub_res.get("sourceType")
+                version = sub_res.get("version", {})
+            if self.sampling_rates:
+                version["samplingRate"] = self.sampling_rates[i]
+            if isinstance(version, dict):
+                versions.append(version)
+
+        result["versions"] = versions
+        if self.source_type:
+            result["sourceType"] = self.source_type.value
+        else:
+            log_error(
+                "[load_dataset_action] dataset dict must be set with"
+                " DatasetConfig.source_type"
+            )
+            raise InvalidArgumentError("dataset dict must be set with source_type")
+        return {"datasets": result}
+
+    def get_dataset_result(
+        self,
+        data_src: DataSource,
+        **kwargs: Any,
+    ) -> Optional[Dict[str, Any]]:
         from qianfan.dataset.data_source import BosDataSource, QianfanDataSource
 
-        if self.dataset is None:
-            raise InvalidArgumentError("dataset or bos_path must be set")
-        if self.dataset.inner_data_source_cache is None:
-            raise InvalidArgumentError("invalid dataset")
-        if isinstance(self.dataset.inner_data_source_cache, QianfanDataSource):
+        if isinstance(data_src, QianfanDataSource):
             log_debug("[load_dataset_action] prepare train-set")
-            qf_data_src = cast(QianfanDataSource, self.dataset.inner_data_source_cache)
+            qf_data_src = cast(QianfanDataSource, data_src)
             is_released = qf_data_src.release_dataset(**kwargs)
             if not is_released:
                 log_error("[load_dataset_action] dataset not released")
                 raise InvalidArgumentError("dataset must be released")
             log_debug("[load_dataset_action] dataset loaded successfully")
-            self.qf_dataset_id = qf_data_src.id
-            self.result = {
-                "datasets": {
-                    "sourceType": console_consts.TrainDatasetSourceType.Platform.value,
-                    "versions": [
-                        {
-                            "versionId": qf_data_src.id,
-                        }
-                    ],
-                }
+            return {
+                "sourceType": console_consts.TrainDatasetSourceType.Platform,
+                "version": {
+                    "versionId": qf_data_src.id,
+                },
             }
-        elif isinstance(self.dataset.inner_data_source_cache, BosDataSource):
+        elif isinstance(data_src, BosDataSource):
             log_debug("[load_dataset_action] prepare train-set in BOS")
-            bos_data_src = cast(BosDataSource, self.dataset.inner_data_source_cache)
-            self.result = {
-                "datasets": {
-                    "sourceType": (
-                        console_consts.TrainDatasetSourceType.PrivateBos.value
-                    ),
-                    "versions": [
-                        {
-                            "versionBosUri": bos_uploader.generate_bos_file_parent_path(
-                                bos_data_src.bucket, bos_data_src.bos_file_path
-                            )
-                        }
-                    ],
-                }
+            bos_data_src = cast(BosDataSource, data_src)
+            return {
+                "sourceType": console_consts.TrainDatasetSourceType.PrivateBos,
+                "version": {
+                    "versionBosUri": bos_uploader.generate_bos_file_path(
+                        bos_data_src.bucket, bos_data_src.bos_file_path
+                    )
+                },
             }
         else:
-            raise InvalidArgumentError("dataset must be set")
-        return self.result
+            return None
+
+    @staticmethod
+    def create_bos_ds_src(bos_uri: str) -> BosDataSource:
+        bucket, bos_path = parse_bos_path(bos_uri)
+        return BosDataSource(
+            region=get_config().BOS_HOST_REGION,
+            bucket=bucket,
+            bos_file_path=bos_path,
+        )
+
+    @staticmethod
+    def get_data_src_from_action_result(
+        dataset_result: Dict[str, Any]
+    ) -> List[DataSource]:
+        res = []
+        dataset_src_type = dataset_result.get("sourceType")
+        for ds_dict in dataset_result.get("versions", []):
+            if dataset_src_type == console_consts.TrainDatasetSourceType.Platform.value:
+                ds = Dataset.load(qianfan_dataset_id=ds_dict.get("versionId"))
+                if ds.inner_data_source_cache:
+                    res.append(
+                        ds.inner_data_source_cache,
+                    )
+            elif (
+                dataset_src_type
+                == console_consts.TrainDatasetSourceType.PrivateBos.value
+            ):
+                bos_ds_src = LoadDataSetAction.create_bos_ds_src(
+                    ds_dict.get("versionBosUri")
+                )
+                res.append(bos_ds_src)
+            elif (
+                dataset_src_type
+                == console_consts.TrainDatasetSourceType.PrivateAfs.value
+            ):
+                continue
+            else:
+                log_warn("[load_dataset_action] invalid dataset source: {ds_dict}")
+        return res
 
     @with_event
     def resume(self, **kwargs: Dict) -> Dict[str, Any]:
@@ -239,19 +323,9 @@ class LoadDataSetAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
         resume method for load dataset action.
 
         Returns:
-            Dict[str, Any]: datasets metainfo including
+            Dict[str, Any]: datasets meta_info including
             dataset_id and dataset_type.
         """
-        if self.qf_dataset_id:
-            log_debug("[load_dataset_action] dataset loading already done")
-            return {
-                "datasets": [
-                    {
-                        "id": self.qf_dataset_id,
-                        "type": console_consts.TrainDatasetType.Platform.value,
-                    }
-                ]
-            }
         log_debug("[load_dataset_action] dataset loading resumed")
         return self._exec(**kwargs)
 
@@ -259,36 +333,45 @@ class LoadDataSetAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
         return self.serialize_helper.serialize(self._action_dict())
 
     def _action_dict(self) -> Dict[str, Any]:
-        qf_ds: Optional[Any] = None
-        if isinstance(self.dataset, str):
-            qf_ds = self.dataset
-        elif (
-            self.dataset is not None
-            and self.dataset.inner_data_source_cache is not None
-        ):
-            assert isinstance(self.dataset.inner_data_source_cache, QianfanDataSource)
-            qf_ds = self.dataset.inner_data_source_cache.id
         meta = {
             "id": self.id,
             "type": LoadDataSetAction.__name__,
-            "ds_id": qf_ds,
-            "dataset_bos": self.bos_path,
+            "datasets": self.get_action_result().get("datasets"),
             "output": self.result,
             "eval_split_ratio": self.eval_split_ratio,
-            "sampling_rate": self.sampling_rate,
-            "corpus_proportion": self.corpus_proportion,
-            "corpus_labels": self.corpus_labels,
-            "corpus_type": self.corpus_type,
         }
+        if self.corpus_config:
+            meta["corpus_config"] = self.corpus_config.dict(
+                by_alias=True, exclude_none=True
+            )
         return meta
 
     @classmethod
     def _load_from_dict(cls, meta: Dict[str, Any]) -> "LoadDataSetAction":
-        dataset = meta.get("ds_id") or meta.get("dataset_bos")
-        assert dataset is not None
+        init_params: Dict[str, Any] = {}
+        if meta.get("datasets") or meta.get("output"):
+            ds_dicts = meta.get("datasets")
+            if ds_dicts is None:
+                ds_output = meta.get("output")
+                assert isinstance(ds_output, dict)
+                ds_dicts = ds_output.get("datasets")
+            assert isinstance(ds_dicts, dict)
+            datasets = LoadDataSetAction.get_data_src_from_action_result(ds_dicts)
+            corpus_config_meta = meta.get("corpus_config")
+            init_params["dataset"] = DatasetConfig(datasets=datasets)
+            if corpus_config_meta:
+                init_params["corpus_config"] = CorpusConfig.parse_obj(
+                    corpus_config_meta
+                )
+            if meta.get("id"):
+                init_params["id"] = meta.get("id")
+            if meta.get("eval_split_ratio"):
+                init_params["dataset"].eval_split_ratio = meta.get("eval_split_ratio")
+        else:
+            log_error(f"unknown load_dataset_action: {meta}")
+            raise ValueError("unknown action meta")
         action = cls(
-            id=meta.get("id"),
-            dataset=dataset,
+            **init_params,
         )
         action.result = meta.get("output")
         return action
@@ -393,11 +476,9 @@ class TrainAction(
                 train mode, e.g. `SFT`, `PostPretrain`, `DPO`. Defaults to None.
             train_type (Optional[str], optional):
                 train_type, must be specified when it's not increment training
-                like 'ERNIE-Bot-turbo-0725'
+                like 'ERNIE-Speed-8K'
             train_config (Optional[TrainConfig], optional):
                 train_config, e.g. `epoch=10, batch_size=32`.
-            base_model (Optional[str], optional):
-                base_mode, like 'ERNIE-Bot-turbo'. Defaults to None.
             task_id (Optional[int], optional):
                 used in incr train, model train task_id. Defaults to None.
             job_id (Optional[int], optional):
@@ -591,7 +672,9 @@ class TrainAction(
 
         assert self.train_config is not None
         hyper_params_dict = {
-            **self.train_config.dict(exclude={"peft_type", "trainset_rate", "extras"}),
+            **self.train_config.dict(
+                exclude={"peft_type", "trainset_rate", "extras", "resource_config"}
+            ),
             **self.train_config.extras,
         }
         hyper_params_dict = {
@@ -615,6 +698,14 @@ class TrainAction(
                 f" { self._last_task_step}"
             )
         assert self.train_config.peft_type is not None
+        # 语料混合配置
+        if input.get("corpus_config"):
+            kwargs["corpus_config"] = input.get("corpus_config")
+        # 训练资源配置
+        if self.train_config.resource_config:
+            kwargs["resource_config"] = self.train_config.resource_config.dict(
+                by_alias=True, exclude_none=True
+            )
         create_task_resp = api.FineTune.V2.create_task(
             job_id=self.job_id,
             params_scale=self.train_config.peft_type,
@@ -643,7 +734,12 @@ class TrainAction(
         while True:
             task_status_resp = api.FineTune.V2.task_detail(
                 task_id=self.task_id,
-                **kwargs,
+                retry_count=kwargs.get(
+                    "retry_count", get_config().TRAINER_STATUS_POLLING_RETRY_TIMES
+                ),
+                backoff_factor=kwargs.get(
+                    "backoff_factor", get_config().TRAINER_STATUS_POLLING_BACKOFF_FACTOR
+                ),
             )
             task_status_result = task_status_resp.get("result", {})
             task_status = task_status_result.get("runStatus")
@@ -688,6 +784,11 @@ class TrainAction(
                 if job_progress >= 50:
                     log_info(f" check vdl report in {self.vdl_link}")
                 time.sleep(get_config().TRAIN_STATUS_POLLING_INTERVAL)
+            elif task_status == "":
+                time.sleep(get_config().TRAIN_STATUS_POLLING_INTERVAL)
+            elif task_status == console_consts.TrainStatus.Waiting:
+                log_info(f"[train_action] {self.job_id}/{self.task_id} queueing...")
+                time.sleep(get_config().TRAIN_STATUS_POLLING_INTERVAL)
             else:
                 raise InternalError(
                     f"[train_action] job: {self.job_name} task:"
@@ -753,18 +854,9 @@ class TrainAction(
         train_mode: console_consts.TrainMode,
         peft_type: Optional[PeftType] = None,
     ) -> TrainConfig:
-        if train_mode == console_consts.TrainMode.PostPretrain:
-            model_info = DefaultPostPretrainTrainConfigMapping.get(
-                model_type,
-            )
-        elif train_mode == console_consts.TrainMode.DPO:
-            model_info = DefaultDPOTrainConfigMapping.get(
-                model_type,
-            )
-        else:
-            model_info = DefaultTrainConfigMapping.get(
-                model_type,
-            )
+        model_info = get_default_train_config(train_mode).get(
+            model_type,
+        )
         if model_info is None or len(model_info) == 0:
             raise InvalidArgumentError(f"can not find default config for {model_type}")
         if peft_type is None:
@@ -892,8 +984,8 @@ class ModelPublishAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
                 **input,
                 "task_id": self.task_id,
                 "job_id": self.job_id,
+                "model_set_id": self.model.set_id,
                 "model_id": self.model.id,
-                "model_version_id": self.model.version_id,
                 "model": self.model,
             }
             return self.result
@@ -923,7 +1015,7 @@ class ModelPublishAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
             },
         }
         if self.model:
-            meta["model_version_id"] = self.model.version_id
+            meta["model_id"] = self.model.id
         if self.result:
             res = copy.deepcopy(self.result)
             if "model" in res:
@@ -941,7 +1033,7 @@ class ModelPublishAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
         )
         action._input = meta.get("input")  # type: ignore
         action.result = meta.get("output")
-        action.model = Model(version_id=meta.get("model_version_id"))
+        action.model = Model(id=meta.get("model_id") or meta.get("model_version_id"))
         action.model.auto_complete_info()
         return action
 
@@ -971,14 +1063,11 @@ class DeployAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
 
     deploy_config: Optional[DeployConfig] = None
     """deploy config include replicas and so on"""
-    model_id: Optional[int] = None
     """model id"""
-    model_id_str: Optional[str] = None
-    """model str id"""
-    model_version_id: Optional[int] = None
-    """model version id"""
-    model_version_id_str: Optional[str] = None
-    """model version str id """
+    model_set_id: Optional[str] = None
+    """model set id"""
+    model_id: Optional[str] = None
+    """model id """
     _input: Optional[Dict[str, Any]] = None
     """input of action"""
     result: Optional[Dict[str, Any]] = None
@@ -1004,12 +1093,12 @@ class DeployAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
             raise InvalidArgumentError("deploy_config must be set")
         if input.get("model") is None:
             self.model_id = input.get("model_id")
-            self.model_version_id = input.get("model_version_id")
+            self.model_set_id = input.get("model_set_id")
             # TODO 迁移成str id
-            if self.model_id is None or self.model_version_id is None:
-                raise InvalidArgumentError("model_id or model_version_id must be set")
+            if self.model_id is None or self.model_set_id is None:
+                raise InvalidArgumentError("model_id or model_set_id must be set")
 
-            self.model = Model(self.model_id, self.model_version_id, auto_complete=True)
+            self.model = Model(self.model_set_id, self.model_id, auto_complete=True)
             self.model.auto_complete_info()
         else:
             self.model = cast(Model, input.get("model"))
@@ -1018,8 +1107,6 @@ class DeployAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
                     "must input with model or model id and version id"
                 )
             self.model.auto_complete_info()
-            self.model_id = self.model.old_id
-            self.model_version_id = self.model.old_version_id
         # 自动补全
 
         return self._exec(**kwargs)
@@ -1029,7 +1116,7 @@ class DeployAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
             raise InvalidArgumentError("deploy_config must be set in deploy._exec")
         assert self.model is not None
         log_debug(
-            f"[deploy_action] try deploy model {self.model.id}_{self.model.version_id}"
+            f"[deploy_action] try deploy model {self.model.set_id}_{self.model.id}"
         )
         self.action_event(
             ActionState.Running,
@@ -1043,7 +1130,7 @@ class DeployAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
         if self.model.service is not None:
             log_debug(
                 "[deploy_action] model"
-                f" {self.model_id}_{self.model_version_id} deployed successfully with"
+                f" {self.model_set_id}_{self.model_id} deployed successfully with"
                 " service:"
                 f" {self.model.service.id} endpoint:{self.model.service.endpoint}"
             )
@@ -1067,13 +1154,11 @@ class DeployAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
                 input args for action resume
 
         """
-        if self.model_id is not None and self.model_version_id is not None:
-            self.model = Model(self.model_id_str, self.model_version_id_str)
+        if self.model_id is not None and self.model_set_id is not None:
+            self.model = Model(self.model_set_id, self.model_id)
             self.model.auto_complete_info()
         elif self.model is None:
-            raise InvalidArgumentError(
-                "either (model_id and version_id) or model must be set"
-            )
+            raise InvalidArgumentError("either (set_id and id) or model must be set")
         return self._exec()
 
     def _action_dict(self) -> Dict[str, Any]:
@@ -1086,8 +1171,8 @@ class DeployAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
                 ),
             },
             "input": {
+                "model_set_id": self.model_set_id,
                 "model_id": self.model_id,
-                "model_version_id": self.model_version_id,
             },
         }
         if self.model is not None and self.model.service is not None:
@@ -1212,8 +1297,8 @@ class EvaluateAction(BaseAction[Dict[str, Any], Dict[str, Any]]):
             llm = input.get("service")
         elif input.get("model"):
             llm = input.get("model")
-        elif input.get("model_id") and input.get("model_version_id"):
-            llm = Model(input["model_id"], input["model_version_id"])
+        elif input.get("model_set_id") and input.get("model_id"):
+            llm = Model(input["model_set_id"], input["model_id"])
         else:
             log_error(f"[evaluation_action] invalid llm input error {self._input}")
             raise InvalidArgumentError(
